%define major 27
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

%define cblasmajor 0
%define cblaslibname %mklibname %{name}cblas %{cblasmajor}

%global __requires_exclude devel\\(libcblas\\)|devel\\(libcblas\\(64bit\\)\\)

Summary:	The GNU Scientific Library for numerical analysis
Name:		gsl
Version:	2.7.1
Release:	%mkrel 2
License:	GPLv2+
Group:		Sciences/Mathematics
URL:		http://www.gnu.org/software/gsl/
Source0:	 https://ftp.gnu.org/gnu/gsl/%{name}-%{version}.tar.xz
Patch0:		gsl-2.6-undefined-symbols.patch
Patch1:		gsl-test.patch
Patch2:		gsl-tol.patch

BuildRequires:	texinfo

%description
The GNU Scientific Library (GSL) is a numerical library for C and
C++ programmers.  It contains over 1000 mathematical routines written
in ANSI C.  The library follows modern coding conventions, and lends
itself to being used in very high level languages (VHLLs).

The library covers the following subject areas:

  Complex Numbers             Roots of Polynomials     Special Functions
  Vectors and Matrices        Permutations             Sorting
  BLAS Support                Linear Algebra           Eigensystems
  Fast Fourier Transforms     Quadrature               Random Numbers
  Quasi-Random Sequences      Random Distributions     Statistics
  Histograms                  N-Tuples                 Monte Carlo Integration
  Simulated Annealing         Differential Equations   Interpolation
  Numerical Differentiation   Chebyshev Approximation  Series Acceleration
  Discrete Hankel Transforms  Root-Finding             Minimization
  Least-Squares Fitting       Physical Constants       IEEE Floating-Point

Further information can be found in the GSL Reference Manual.

Install the gsl package if you need a library for high-level
scientific numerical analysis.

%package	progs
Summary:	Programs of the Scientific Library
Group:		Sciences/Mathematics
Requires:	%{libname} = %{version}-%{release}

%description	progs
Here're the GNU Scientific Library (GSL) programs:
 - gsl-histogram: computes a histogram of the data on stdin
                  using n bins from xmin to xmax.
 - gsl-randist: generates n samples from a given distribution DIST
                with given parameters

%package	doc
Summary:	Documentation of the Scientific Library
Group:		Documentation
BuildArch:	noarch

%description	doc
This is the documentation in info format of the GNU Scientific Library (GSL).
This doc can be viewed through info, pinfo, konqueror, gnome yelp, ...

%package -n	%{libname}
Summary:	Shared libraries for Scientific Library
Group:		System/Libraries
Obsoletes:   lib64gsl19
#Obsoletes:   lib64gsl25
Obsoletes:   luminance = 2.3.1
Obsoletes:   scidavis = 1.22

%description -n	%{libname}
The GNU Scientific Library (GSL) is a numerical library for C and
C++ programmers.  It contains over 1000 mathematical routines written
in ANSI C.  The library follows modern coding conventions, and lends
itself to being used in very high level languages (VHLLs).

 The library covers the following subject areas:

  Complex Numbers             Roots of Polynomials     Special Functions
  Vectors and Matrices        Permutations             Sorting
  BLAS Support                Linear Algebra           Eigensystems
  Fast Fourier Transforms     Quadrature               Random Numbers
  Quasi-Random Sequences      Random Distributions     Statistics
  Histograms                  N-Tuples                 Monte Carlo Integration
  Simulated Annealing         Differential Equations   Interpolation
  Numerical Differentiation   Chebyshev Approximation  Series Acceleration
  Discrete Hankel Transforms  Root-Finding             Minimization
  Least-Squares Fitting       Physical Constants       IEEE Floating-Point

Further information can be found in the GSL Reference Manual.


%package -n	%{cblaslibname}
Summary:	Shared libraries for Scientific Library
Group:		System/Libraries

%description -n	%{cblaslibname}
The GNU Scientific Library (GSL) cblas library.

%package -n	%{develname}
Summary:	Development files for Scientific Library
Group:		Development/Libraries
Requires:	%{libname} = %{version}-%{release}
Requires:	%{cblaslibname} = %{version}-%{release}
Requires:	libatlas-devel
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n	%{develname}
The gsl package includes the GNU Scientific Library (GSL). The GSL is a
collection of routines for numerical analysis, written in C.
It now includes a random number suite, an FFT package, simulated annealing
and root finding.  In the future, it will include numerical and Monte Carlo
integration and special functions.
Linking against the GSL allows programs to access functions which can
handle many of the problems encountered in scientific computing.

These are the static libs and include headers for developers.

%prep
%setup -q
%apply_patches

%build
autoreconf -fi

# disable FMA
%ifarch aarch64
export CFLAGS="%{optflags} -ffp-contract=off"
%endif

%configure2_5x --disable-static
%make_build

%install
rm -rf %buildroot
%make_install

find %{buildroot} -name '*.la' -delete

%post doc
%_install_info gsl-ref.info

%postun doc
%_remove_install_info gsl-ref.info

%files progs
%{_bindir}/gsl-histogram
%{_bindir}/gsl-randist
%{_mandir}/man1/gsl-histogram*
%{_mandir}/man1/gsl-randist*

%files doc
%{_infodir}/*info*

%files -n %{libname}
%{_libdir}/libgsl.so.%{major}*

%files -n %{cblaslibname}
%{_libdir}/libgslcblas.so.%{cblasmajor}*

%files -n %{develname}
%doc BUGS ChangeLog TODO doc/examples/
%{_bindir}/gsl-config
%{_datadir}/aclocal/*.m4
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so
%{_mandir}/man3/*
%{_mandir}/man1/gsl-config.*


%changelog
* Tue Jan 02 2023 tex - 2.7.1-2pclos2023
- obsolete some leftover old pkgs

* Thu Dec 29 2022 pp - 2.7.1-1pclos2023
- new version

* Wed Oct 23 2019 tex - 2.6-1pclos2019
- new version: 2.6
- now libmajor is 25
